==> openshift-client-4.13.0-sources.jar: io/fabric8/openshift/client/handlers/InfrastructureHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.InfrastructureOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.Infrastructure;
import io.fabric8.openshift.api.model.InfrastructureBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class InfrastructureHandler implements ResourceHandler<Infrastructure, InfrastructureBuilder> {

  @Override
  public String getKind() {
    return Infrastructure.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "config.openshift.io/v1";
    }

  @Override
  public Infrastructure create(OkHttpClient client, Config config, String namespace, Infrastructure item) {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public Infrastructure replace(OkHttpClient client, Config config, String namespace, Infrastructure item) {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public Infrastructure reload(OkHttpClient client, Config config, String namespace, Infrastructure item) {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public InfrastructureBuilder edit(Infrastructure item) {
    return new InfrastructureBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, Infrastructure item) {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Infrastructure item, Watcher<Infrastructure> watcher) {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Infrastructure item, String resourceVersion, Watcher<Infrastructure> watcher) {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Infrastructure item, ListOptions options, Watcher<Infrastructure> watcher) {
  return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public Infrastructure waitUntilReady(OkHttpClient client, Config config, String namespace, Infrastructure item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public Infrastructure waitUntilCondition(OkHttpClient client, Config config, String namespace, Infrastructure item, Predicate<Infrastructure> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.3.0-sources.jar: io/fabric8/openshift/client/handlers/InfrastructureHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.InfrastructureOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.Infrastructure;
import io.fabric8.openshift.api.model.InfrastructureBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class InfrastructureHandler implements ResourceHandler<Infrastructure, InfrastructureBuilder> {

  @Override
  public String getKind() {
    return Infrastructure.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "config.openshift.io/v1";
    }

  @Override
  public Infrastructure create(OkHttpClient client, Config config, String namespace, Infrastructure item, boolean dryRun) {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public Infrastructure replace(OkHttpClient client, Config config, String namespace, Infrastructure item, boolean dryRun) {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public Infrastructure reload(OkHttpClient client, Config config, String namespace, Infrastructure item) {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public InfrastructureBuilder edit(Infrastructure item) {
    return new InfrastructureBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, Infrastructure item, boolean dryRun) {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Infrastructure item, Watcher<Infrastructure> watcher) {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Infrastructure item, String resourceVersion, Watcher<Infrastructure> watcher) {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, Infrastructure item, ListOptions options, Watcher<Infrastructure> watcher) {
  return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public Infrastructure waitUntilReady(OkHttpClient client, Config config, String namespace, Infrastructure item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public Infrastructure waitUntilCondition(OkHttpClient client, Config config, String namespace, Infrastructure item, Predicate<Infrastructure> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new InfrastructureOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
